part of openrqm.api;



class ElementsApi {
  final ApiClient apiClient;

  ElementsApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Get all elements with HTTP info returned
  ///
  /// 
  Future<Response> getElementsWithHttpInfo({ int documentid }) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/elements".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(documentid != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "documentid", documentid));
    }

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get all elements
  ///
  /// 
  Future<List<RQMElement>> getElements({ int documentid }) async {
    Response response = await getElementsWithHttpInfo( documentid: documentid );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<RQMElement>') as List).map((item) => item as RQMElement).toList();
    } else {
      return null;
    }
  }

}
